# PermitAlterationSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**permit_alteration_reference_number** | **str** |  | 
**date_created** | **datetime** |  | 
**deadline_date** | **datetime** |  | 
**alteration_status** | [**AlterationStatusResponse**](AlterationStatusResponse.md) |  | 
**alteration_status_string** | **str** |  | 
**alteration_type** | [**AlterationTypeResponse**](AlterationTypeResponse.md) |  | 
**alteration_type_string** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

